S600SDK class

Constructors

S600SDK()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

printBarCode(String qrData) Future<void>
printerTest() Future<String>
printImage(Uint8List imageBytes) Future<void>
printQrCode(String qrData) Future<void>
printText(List<Map<String, dynamic>> textList) Future<void>
readThaiIDCard() Future<Map<String, dynamic>>